@@ -41,7 +41,6 @@ from setproctitle import setproctitle
 from sqlalchemy import select
 
 import airflow.settings as settings
-from airflow.api_internal.internal_api_call import InternalApiConfig
 from airflow.configuration import conf
 from airflow.exceptions import AirflowException, AirflowProviderDeprecationWarning, AirflowTaskTimeout
 from airflow.executors.base_executor import BaseExecutor
@@ -161,10 +160,6 @@ def _execute_in_fork(command_to_exec: CommandType, celery_task_id: str | None =
     try:
         from airflow.cli.cli_parser import get_parser
 
-        if not InternalApiConfig.get_use_internal_api():
-            settings.engine.pool.dispose()
-            settings.engine.dispose()
-
         parser = get_parser()
         # [1:] - remove "airflow" from the start of the command
         args = parser.parse_args(command_to_exec[1:])
